# smlmLP

```text
Author        : Lancelot PINCET
GitHub        : https://github.com/LancelotPincet/smlmLP
HTTPS         : https://github.com/LancelotPincet/smlmLP.git
SSH           : git@github.com:LancelotPincet/smlmLP.git
PyPI          : https://pypi.org/project/smlmLP
Docs          : https://smlmLP.readthedocs.io
```

**A python library for Single Molecule Localization Microscopy.**

smlmLP is available on [PyPI](https://pypi.org/project/smlmLP) for pip installs.
For more information, do not hesitate to consult the [Documentation](https://smlmLP.readthedocs.io).

---

## MIT License

<details>
<summary>details</summary>

Intellectual property behind this Library is protected via an [MIT license](LICENSE). This means everyone can *freely* use it in a personnal, academic or commercial manner, if they **keep the copyright name** at the top of the codes.

The library can be redistributed, *with or without modifications*, in open or closed projects. However the **MIT license must be conserved**. For example in a commercial closed project, this means the **copyright and license must be visible somewhere**, like in the documentation or credits.

The license also explains that the **code performances are not warrantied**, and you are responsible for how you are using it. For more information on your rights and obligations please refer to [descriptive websites](https://en.wikipedia.org/wiki/MIT_License), or contact author for approvales.

</details>
